@@ -105,7 +105,7 @@ KGameThemeSelector::KGameThemeSelector(KGameThemeProvider *provider, Options opt
     // setup KNS button
     if (options & EnableNewStuffDownload) {
         QString name = QCoreApplication::applicationName() + QStringLiteral(".knsrc");
-        d->m_knsButton = new KNSWidgets::Button(i18n("Get New Themes..."), name, this);
+        d->m_knsButton = new KNSWidgets::Button(i18nc("@action:button", "Download New Themes…"), name, this);
         QHBoxLayout *hLayout = new QHBoxLayout();
         hLayout->addStretch(1);
         hLayout->addWidget(d->m_knsButton);
@@ -279,7 +279,7 @@ void KGameThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     {
         QString name = index.data(Qt::DisplayRole).toString();
         if (name.isEmpty())
-            name = i18n("[No name]");
+            name = i18nc("@item name of theme, missing", "[No name]");
         texts << name;
         QFont theFont(painter->font());
         theFont.setBold(true);
@@ -295,7 +295,7 @@ void KGameThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     {
         QString author = index.data(AuthorRole).toString();
         if (!author.isEmpty()) {
-            const QString authorString = ki18nc("Author attribution, e.g. \"by Jack\"", "by %1").subs(author).toString();
+            const QString authorString = i18nc("@info author attribution", "By %1", author);
             texts << authorString;
             QFont theFont(painter->font());
             theFont.setItalic(true);
